<?php
/**
 * Wacko functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Wacko
 */

if ( ! function_exists( 'wacko_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function wacko_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Wacko, use a find and replace
		 * to change 'wacko' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'wacko', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'wacko-blog', 340,  210, true );
		add_image_size( 'wacko-project', 360,  240, true );
		add_image_size( 'wacko-feautres', 360, 207, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'wacko' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'wacko_custom_background_args', array(
			'default-color' => 'f6f6f6',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );


		// Theme Activation Notice
		global $pagenow;
		
		if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
			add_action( 'admin_notices', 'wacko_theme_activation_notice' );
		}
	}
endif;
add_action( 'after_setup_theme', 'wacko_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function wacko_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'wacko_content_width', 640 );
}
add_action( 'after_setup_theme', 'wacko_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function wacko_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'wacko' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'wacko' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer: One', 'wacko' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widget here. This section is used for top footer.', 'wacko' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<header class="entry-header"><h4 class="widget-title">',
		'after_title'   => '</h4></header>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer: Two', 'wacko' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widget here. This section is used for top footer.', 'wacko' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<header class="entry-header"><h4 class="widget-title">',
		'after_title'   => '</h4></header>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer: Three', 'wacko' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widget here. This section is used for top footer.', 'wacko' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<header class="entry-header"><h4 class="widget-title">',
		'after_title'   => '</h4></header>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer: Four', 'wacko' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widget here. This section is used for top footer.', 'wacko' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<header class="entry-header"><h4 class="widget-title">',
		'after_title'   => '</h4></header>',
	) );
}
add_action( 'widgets_init', 'wacko_widgets_init' );

if ( ! function_exists( 'wacko_fonts_url' ) ) {
	/**
	 * Register Google fonts.
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function wacko_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		/* translators: If there are characters in your language that are not supported by Titillium Web, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Titillium Web', 'wacko' ) ) {
			$fonts[] = 'Titillium Web:300,400,600,700';
		}		

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}
}

/**
 * Enqueue scripts and styles.
 */
function wacko_scripts() {

	$theme_options  = wacko_theme_options();

	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );

	wp_enqueue_style( 'wacko-fonts', wacko_fonts_url() );

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css' );

	wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.css' );

	wp_enqueue_style( 'wacko-style', get_stylesheet_uri() );

	wp_enqueue_style( 'wacko-media', get_template_directory_uri() . '/assets/css/media.css' );

	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array('jquery'), '3.3.7', true );

	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '2.2.1', true );

	wp_enqueue_script( 'wacko-custom', get_template_directory_uri() . '/assets/js/wacko-custom.js', array('jquery'), '20151215', true );

	if( 1 === $theme_options['sticky_header'] ){
		wp_enqueue_script( 'wacko-sticky-header', get_template_directory_uri() . '/assets/js/sticky.header.js', array('jquery'), '20151216', true );
	}

	wp_enqueue_script( 'wacko-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '20151217', true );

	wp_enqueue_script( 'wacko-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151218', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'wacko_scripts' );

/**
 * Load Wacko Functions.
 */
require get_template_directory() . '/inc/init-functions.php';
